@@ -647,18 +647,22 @@ def test_m2m_cscope_call():
     Test m2m addedvalue when called in terminal.
     """
     # RUN THE COMMAND
-    inppath = 'metabolic_data/'
-    respath = 'addedvalue_output/'
+    inppath = 'metabolic_data'
+    respath = 'addedvalue_output'
+    toy_bact_tgz_path = os.path.join(inppath, 'toy_bact.tar.gz')
+    toy_bact_path = os.path.join(respath, 'toy_bact')
+    seeds_path = os.path.join(inppath, 'seeds_toy.sbml')
+
     if not os.path.exists(respath):
         os.makedirs(respath)
-    with tarfile.open(inppath + 'toy_bact.tar.gz') as tar:
+    with tarfile.open(toy_bact_tgz_path) as tar:
         tar.extractall(path=respath)
     subprocess.call([
-        'm2m', 'iscope', '-n', respath + '/toy_bact', '-o',
-        respath, '-s', inppath + '/seeds_toy.sbml',
+        'm2m', 'iscope', '-n', toy_bact_path, '-o',
+        respath, '-s', seeds_path,
         '-q'
     ])
-    iscope_file = respath + 'indiv_scopes/rev_iscope.tsv'
+    iscope_file = os.path.join(*[respath, 'indiv_scopes', 'rev_iscope.tsv'])
 
     compounds = {}
     compounds_name = {}
